@@ -865,7 +865,8 @@ def _make_template(s: str):
     s = re.sub(r"\b([a-zA-Z0-9_]+)\b", replace_id, s)
     if leftovers:
         from warnings import warn
-        warn("leftover words in identifier prefixing: " + " ".join(leftovers))
+        warn("Leftover words in identifier prefixing: " + " ".join(leftovers),
+             stacklevel=3)
 
     return mako.template.Template(s, strict_undefined=True)     # type: ignore
 
@@ -1085,22 +1086,22 @@ class GenericScanKernelBase(ABC):
 
         from pyopencl.characterize import has_double_support
 
-        self.code_variables = dict(
-            np=np,
-            dtype_to_ctype=dtype_to_ctype,
-            preamble=preamble,
-            name_prefix=name_prefix,
-            index_dtype=self.index_dtype,
-            scan_dtype=dtype,
-            is_segmented=self.is_segmented,
-            arg_dtypes=arg_dtypes,
-            arg_ctypes=arg_ctypes,
-            scan_expr=_process_code_for_macro(scan_expr),
-            neutral=_process_code_for_macro(neutral),
-            is_gpu=bool(self.devices[0].type & cl.device_type.GPU),
-            double_support=all(
+        self.code_variables = {
+            "np": np,
+            "dtype_to_ctype": dtype_to_ctype,
+            "preamble": preamble,
+            "name_prefix": name_prefix,
+            "index_dtype": self.index_dtype,
+            "scan_dtype": dtype,
+            "is_segmented": self.is_segmented,
+            "arg_dtypes": arg_dtypes,
+            "arg_ctypes": arg_ctypes,
+            "scan_expr": _process_code_for_macro(scan_expr),
+            "neutral": _process_code_for_macro(neutral),
+            "is_gpu": bool(self.devices[0].type & cl.device_type.GPU),
+            "double_support": all(
                 has_double_support(dev) for dev in devices),
-            )
+            }
 
         index_typename = dtype_to_ctype(self.index_dtype)
         scan_typename = dtype_to_ctype(dtype)
@@ -1142,7 +1143,8 @@ class GenericScanKernelBase(ABC):
 
 generic_scan_kernel_cache = WriteOncePersistentDict(
         "pyopencl-generated-scan-kernel-cache-v1",
-        key_builder=_NumpyTypesKeyBuilder())
+        key_builder=_NumpyTypesKeyBuilder(),
+        in_mem_cache_size=0)
 
 
 class GenericScanKernel(GenericScanKernelBase):
