@@ -1303,6 +1303,9 @@ def test_compile_link(ctx_factory):
     if platform.name == "Apple":
         pytest.skip("Apple doesn't like our compile/link test")
 
+    # as of pocl 5.0
+    _xfail_if_pocl_gpu(ctx.devices[0], "compile/link")
+
     queue = cl.CommandQueue(ctx)
     vsink_prg = cl.Program(ctx, """//CL//
         void value_sink(float x)
